# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program (see the file COPYING); if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

import datetime
import unittest

import rapport.timeframe


class TimeframeTestCase(unittest.TestCase):
    def setUp(self):
        self.now = datetime.datetime.now()
        self.a_day_ago = self.now - datetime.timedelta(days=1)
        self.five_hours_ago = self.now - datetime.timedelta(hours=5)


class TestTimeframe(TimeframeTestCase):
    def setUp(self):
        super(TestTimeframe, self).setUp()
        self.timeframe = rapport.timeframe.Timeframe(start=self.a_day_ago,
                                                     end=self.now)

    def test_timeframe(self):
        self.assertEqual(self.a_day_ago, self.timeframe.start)
        self.assertEqual(self.now, self.timeframe.end)
        self.assertTrue(self.timeframe.contains(self.five_hours_ago))

    def test_timeframe_str(self):
        self.assertEqual("timeframe", str(self.timeframe))


class TestCurrentWeekTimeframe(TimeframeTestCase):
    def setUp(self):
        super(TestCurrentWeekTimeframe, self).setUp()
        self.timeframe = rapport.timeframe.CurrentWeekTimeframe()

    def test_current_week_timeframe(self):
        start = self.timeframe.start
        self.assertEqual(start.hour, 0)
        self.assertEqual(start.minute, 0)
        self.assertEqual(start.second, 0)
        self.assertTrue(self.timeframe.contains(self.five_hours_ago))

    def test_current_week_timeframe_str(self):
        self.assertEqual("current_week", str(self.timeframe))


class TestCurrentMonthTimeframe(TimeframeTestCase):
    def setUp(self):
        super(TestCurrentMonthTimeframe, self).setUp()
        self.timeframe = rapport.timeframe.CurrentMonthTimeframe()

    def test_current_week_timeframe(self):
        start = self.timeframe.start
        self.assertEqual(start.hour, 0)
        self.assertEqual(start.minute, 0)
        self.assertEqual(start.second, 0)
        self.assertTrue(self.timeframe.contains(self.five_hours_ago))

    def test_current_week_timeframe_str(self):
        self.assertEqual("current_month", str(self.timeframe))


class TestNLastDaysTimeframe(TimeframeTestCase):
    def setUp(self):
        super(TestNLastDaysTimeframe, self).setUp()
        self.timeframe = rapport.timeframe.NLastDaysTimeframe()

    def test_n_last_days_timeframe(self):
        self.assertTrue(self.timeframe.contains(self.five_hours_ago))
        self.assertEqual(self.timeframe.start.hour, self.timeframe.end.hour)
        self.assertEqual(self.timeframe.start.minute,
                         self.timeframe.end.minute)
        self.assertEqual(self.timeframe.start.second,
                         self.timeframe.end.second)

    def test_last_seven_days_timeframe_str(self):
        self.assertEqual("n_last_days", str(self.timeframe))



# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program (see the file COPYING); if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA


import os
import sys
import unittest

from rapport import __version__
from rapport.util import silent_popen


class CLIFunctionalTestCase(unittest.TestCase):
    def setUp(self):
        self.result = "rapport {0}\n".format(__version__)

    def test_call_rapport_cli(self):
        args = [sys.executable, "rapport/cli.py", "--version"]
        self.assertEqual(silent_popen(args), self.result)

    def test_call_script_wrapper(self):
        args = ["scripts/rapport", "--version"]
        # The script is meant to be with rapport installed, i.e. not
        # from the (development) tree. Thus we have to adjust PYTHONPATH:
        env = os.environ.copy()
        env.update({"PYTHONPATH": "."})
        self.assertEqual(silent_popen(args, env=env), self.result)



#!/usr/bin/env python

# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program (see the file COPYING); if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import rapport
from rapport.setup import get_cmdclass, parse_requirements


install_requires = parse_requirements("tools/install-requires.txt")
tests_requires = parse_requirements("tools/test-requires.txt")

setup(
    name="rapport",
    version=rapport.__version__,
    license="GPLv2",
    description="Work report generator for the lazy",
    long_description=open("README.rst").read(),
    author=rapport.__author__.rsplit(" ", 1)[0],
    author_email=rapport.__author__.rsplit(" ", 1)[1][1:-1],
    url="http://github.com/saschpe/rapport",
    scripts=["scripts/rapport"],
    packages=["rapport", "rapport.plugins"],
    package_data={"rapport": ["templates/email/*",
                              "templates/plugin/*",
                              "templates/web/*"]},
    data_files=[("/etc/rapport/", ["config/rapport.conf"])],
    setup_requires=install_requires + tests_requires,
    install_requires=install_requires,
    cmdclass=get_cmdclass(),
    tests_require=tests_requires,
    test_suite="nose.collector",
    requires_python=">=2.7,<3",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX",
        "Programming Language :: Python",
    ],
)



# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program (see the file COPYING); if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA


import os
import unittest

from rapport.setup import parse_requirements


class SetupTestCase(unittest.TestCase):
    def setUp(self):
        self.install_reqs_file = os.path.join("test", "unit", "fixtures",
                                              "setup", "install-requires.txt")
        self.test_reqs_file = os.path.join("test", "unit", "fixtures",
                                           "setup", "test-requires.txt")
        self.install_reqs = ["argparse", "launchpadlib", "lxml", "Jinja2",
                             "paramiko", "requests"]
        self.test_reqs = ["nose"]

    def test_parse_requirements(self):
        install_reqs = parse_requirements(self.install_reqs_file)
        test_reqs = parse_requirements(self.test_reqs_file)

        self.assertEqual(install_reqs, self.install_reqs)
        self.assertEqual(test_reqs, self.test_reqs)
